@@ -12,6 +12,7 @@ namespace Tomboy
 	{
 		bool editing_title;
 		Gtk.TextTag title_tag;
+		HIGMessageDialog title_taken_dialog = null; 
 
 		public override void Initialize ()
 		{
@@ -119,7 +120,7 @@ namespace Tomboy
 			Buffer.ApplyTag (title_tag, TitleStart, TitleEnd);
 
 			// NOTE: Use "(Untitled #)" for empty first lines...
-			string title = TitleStart.GetText (TitleEnd).Trim ();
+			string title = TitleStart.GetSlice (TitleEnd).Trim ();
 			if (title == string.Empty)
 				title = GetUniqueUntitled ();
 
@@ -167,8 +168,7 @@ namespace Tomboy
 				return false;
 			}
 
-			Logger.Debug (string.Format ("Renaming note from {0} to {1}",
-			                             Note.Title, title));
+			Logger.Debug ("Renaming note from {0} to {1}", Note.Title, title);
 			Note.Title = title;
 			return true;
 		}
@@ -186,17 +186,26 @@ namespace Tomboy
 								  "for this note before " +
 								  "continuing."),
 					       title);
-
-			HIGMessageDialog dialog = 
-				new HIGMessageDialog (Window,
+			
+			/// Only pop open a warning dialog when one isn't already present
+			/// Had to add this check because this method is being called twice.
+			if (title_taken_dialog == null) {
+				title_taken_dialog =
+					new HIGMessageDialog (Window,
 						      Gtk.DialogFlags.DestroyWithParent,
 						      Gtk.MessageType.Warning,
 						      Gtk.ButtonsType.Ok,
 						      Catalog.GetString ("Note title taken"),
 						      message);
-
-			dialog.Run ();
-			dialog.Destroy ();
+				title_taken_dialog.Modal = true;
+				title_taken_dialog.Response +=
+					delegate (object sender, Gtk.ResponseArgs args) {
+						title_taken_dialog.Destroy ();
+						title_taken_dialog = null;
+					};
+			}
+			
+			title_taken_dialog.Present ();
 		}
 	}
 
@@ -392,7 +401,7 @@ namespace Tomboy
 
 		string GetUrl (Gtk.TextIter start, Gtk.TextIter end)
 		{
-			string url = start.GetText (end);
+			string url = start.GetSlice (end);
 
 			// FIXME: Needed because the file match is greedy and
 			// eats a leading space.
@@ -466,7 +475,7 @@ namespace Tomboy
 
 			Buffer.RemoveTag (url_tag, start, end);
 
-			for (Match match = regex.Match (start.GetText (end)); 
+			for (Match match = regex.Match (start.GetSlice (end)); 
 			     match.Success; 
 			     match = match.NextMatch ()) {
 				System.Text.RegularExpressions.Group group = match.Groups [1];
@@ -749,7 +758,7 @@ namespace Tomboy
 
 		void HighlightInBlock (Gtk.TextIter start, Gtk.TextIter end) 
 		{
-			ArrayList hits = Manager.TitleTrie.FindMatches (start.GetText (end));
+			ArrayList hits = Manager.TitleTrie.FindMatches (start.GetSlice (end));
 			foreach (TrieHit hit in hits) {
 				DoHighlight (hit, start, end);
 			}
